@@ -1,18 +1,16 @@
 # -*- coding: utf-8 -*-
 import datetime
-from copy import deepcopy
 from collections import defaultdict
-from collections import namedtuple
 
+from pydeform.exceptions import NotFoundError
+from pydeform.six import PY2
 from pydeform.utils import (
-    uri_join,
+    do_http_request,
+    flatten,
     format_date,
     format_datetime,
-    flatten,
-    do_http_request,
+    uri_join
 )
-from pydeform.exceptions import NotFoundError
-
 
 PARAMS_DEFINITIONS = {
     'login_email': {
@@ -80,6 +78,13 @@ PARAMS_DEFINITIONS = {
     },
 }
 
+if PY2:
+    FILE_TYPE = file
+else:
+    from io import IOBase
+    FILE_TYPE = IOBase
+
+
 def get_params_by_destination(params, definitions):
     response = defaultdict(dict)
     for param_key, param_value in params.items():
@@ -145,7 +150,7 @@ def get_payload(params, definitions):
     if params_has_files:
         final_data = flatten(final_data)
         for key, value in final_data.items():
-            if not isinstance(value, file):
+            if not isinstance(value, FILE_TYPE):
                 final_data[key] = (None, value)
     else:
         final_data = {
@@ -180,7 +185,7 @@ def prepare_payload(data):
             if with_files and not items_with_files:
                 items_with_files = True
         return items_with_files, dict(items)
-    elif isinstance(data, file):
+    elif isinstance(data, FILE_TYPE):
         return True, data
     else:
         return False, data
@@ -196,7 +201,7 @@ def iterate_by_pagination(method,
         }
     }
     page = 0
-    if not 'params' in request_kwargs:
+    if 'params' not in request_kwargs:
         request_kwargs['params'] = {}
     while True:
         if response_result.get('links', {}).get('next'):
@@ -209,7 +214,7 @@ def iterate_by_pagination(method,
                     requests_session=requests_session,
                     request_defaults=request_defaults,
                 )
-            except NotFoundError as e:
+            except NotFoundError:
                 break
             response_result = response.json()['result']
             for i in response_result['items']:
